<template>
  <div>
    <basic-container>
      <div class="task-div-title">
        <div style="margin-left:15px;">
          <span style="font-size: 17px;font-weight: bold;color: #2d2d2d;"
            >生成项编辑</span
          >
        </div>
      </div>
      <div
        style="margin-bottom: 10px;margin-left: 15px; display:inline-block;width: 80%;margin-top: 30px"
      >
        <el-form
          :model="formData"
          class="l-mes"
          style="margin-left: 10px"
          ref="form"
          :rules="rules"
          label-width="100px"
        >
          <el-form-item prop="materialCode" label="物料编码">
            <el-select
              placeholder="请选择物料编码"
              v-model="formData.materialCode"
              clearable
            >
              <el-option
                v-for="item in materialCodes"
                :key="item.key"
                :label="item.cusMaterialCode"
                :value="item.cusMaterialCode"
              >
              </el-option>
            </el-select>
          </el-form-item>
          <el-form-item prop="barTime" label="条码日期">
            <el-date-picker
              v-model="formData.barTime"
              type="date"
              placeholder="选择日期"
              format="yyyy-MM-dd"
              value-format="yyyy-MM-dd HH:mm:ss"
            >
              >
            </el-date-picker>
          </el-form-item>
          <el-form-item prop="isStandardLen" label="是否标长">
            <el-select
              v-model="formData.isStandardLen"
              placeholder="请选择"
              clearable
              @change="changeStandardLen"
            >
              <el-option
                v-for="item in isStandardLenOptions"
                :key="item.key"
                :label="item.label"
                :value="item.value"
              >
              </el-option>
            </el-select>
          </el-form-item>
          <el-form-item prop="len" label="长度">
            <el-input
              placeholder="请输入长度"
              v-model="formData.length"
              type="number"
              clearable
            ></el-input>
          </el-form-item>
          <el-form-item prop="genCount" label="生成数量">
            <el-input
              placeholder="请输入生成数量"
              v-model="formData.genCount"
              type="number"
            ></el-input>
          </el-form-item>
        </el-form>
        <el-row type="flex" justify="space-around" style="margin-top: 50px">
          <el-button type="primary" @click="submitForm()">生成19条码</el-button>
          <el-button @click="resetForm">清除</el-button>
        </el-row>
      </div>
    </basic-container>
  </div>
</template>

<script>
import { addCode19, getHwMaterialCode } from '@/api/huawei/code19gen'
export default {
  name: 'genForm',
  data() {
    return {
      formData: {
        materialCode: '',
        barTime: '',
        isStandardLen: '',
        length: '',
        genCount: ''
      },
      rules: {
        materialCode: [
          { required: true, message: '请选择物料编码', trigger: 'blur' }
        ],
        barTime: [
          { required: true, message: '请选择条码日期', trigger: 'blur' }
        ],
        isStandardLen: [
          { required: true, message: '请选择是否标长', trigger: 'blur' }
        ],
        length: [{ required: true, message: '请填写长度', trigger: 'blur' }],
        genCount: [
          { required: true, message: '请填写生成数量', trigger: 'blur' }
        ]
      },
      isStandardLenOptions: [
        {
          value: 0,
          label: '非标'
        },
        {
          value: 1,
          label: '标长'
        }
      ],
      materialCodes: [
        // {
        //   value: '0001',
        //   label: 'C00011'
        // }
      ]
    }
  },
  created() {
    this.getCusMaterialCode()
  },
  methods: {
    submitForm() {
      this.$refs.form.validate((valid) => {
        if (valid) {
          if (this.formData.length >= 1000) {
            this.$message.error('长度需小于1000')
            return
          }
          addCode19(this.formData)
            .then((data) => {
              this.$message.success('生成成功')
              // 刷新列表
              this.$emit('updateList')
            })
            .catch(() => {
              this.$message.error('生成失败')
            })
        }
      })
    },
    resetForm() {
      this.$refs.form.resetFields()
    },
    changeStandardLen() {
      if (this.formData.isStandardLen === 1) {
        this.formData.length = 600
      }
    },
    getCusMaterialCode() {
      getHwMaterialCode()
        .then((response) => {
          console.log(response)
          this.materialCodes = response.data.data
        })
        .catch(() => {})
    }
  }
}
</script>

<style scoped></style>
